@@ -1,8 +1,9 @@
 check.popdataDWM <- function(tabs, tabIDs, pltassgnx, pltassgnid,
-	pfromqry, palias, pjoinid, whereqry, adj, ACI, pltx=NULL, puniqueid="CN", 
-	dsn=NULL, condid="CONDID", areawt="CONDPROP_UNADJ",
-	nonsamp.cfilter=NULL, nullcheck=FALSE, cvars2keep=NULL, 
-	dwmvars2keep=NULL, gui=FALSE){
+     pfromqry, palias, pjoinid, whereqry, 
+     adj, ACI, pltx = NULL, puniqueid = "CN", dsn = NULL, dbconn = NULL,
+     condid = "CONDID", areawt = "CONDPROP_UNADJ",
+     nonsamp.cfilter = NULL, nullcheck = FALSE, pvars2keep = NULL,
+	 cvars2keep = NULL, dwmvars2keep = NULL, gui = FALSE){
 
   ###################################################################################
   ## DESCRIPTION: Checks data inputs for DWM estimation
@@ -61,9 +62,13 @@ check.popdataDWM <- function(tabs, tabIDs, pltassgnx, pltassgnid,
 
   ## Check dsn and create queries to get population subset from database
   ###################################################################################
-  if (!is.null(dsn) && getext(dsn) %in% c("sqlite", "db", "db3", "sqlite3", "gpkg")) {
+  if (!is.null(dbconn) || 
+	(!is.null(dsn) && getext(dsn) %in% c("sqlite", "db", "db3", "sqlite3", "gpkg"))) {
+
     datindb <- TRUE
-    dbconn <- DBtestSQLite(dsn, dbconnopen=TRUE, showlist=FALSE)
+    if (is.null(dbconn)) {
+      dbconn <- DBtestSQLite(dsn, dbconnopen=TRUE, showlist=FALSE)
+    }
     tablst <- DBI::dbListTables(dbconn)
     chk <- TRUE
     SCHEMA. <- NULL
@@ -209,6 +214,13 @@ check.popdataDWM <- function(tabs, tabIDs, pltassgnx, pltassgnid,
   ## Check condition data
   ###################################################################################
   pltcondnmlst <- names(pltcondx)
+  
+    ## Check for pvars2keep
+  #############################################################################
+  if (!all(pvars2keep %in% pltcondnmlst)) {
+    pvars2keep <- pvars2keep[!pvars2keep %in% pltcondnmlst] 
+    message("variables not in dataset: ", toString(pvars2keep))
+  }
 
   ## Check for COND_STATUS_CD and create ACI filter
   #############################################################################
