@@ -54,6 +54,10 @@
 #' syntax (e.g., 'STATUSCD == 1').
 #' @param estseed String. Use seedling data only or add to tree data. Seedling
 #' estimates are only for counts (estvar='TPA_UNADJ')-('none', 'only', 'add').
+#' @param woodland String. If woodland = 'Y', include woodland tree species  
+#' where measured. If woodland = 'N', only include timber species. See 
+#' FIESTA::ref_species$WOODLAND ='Y/N'. If woodland = 'only', only include
+#' woodland species.
 #' @param landarea String. The condition-level filter for defining land area
 #' ('ALL', 'FOREST', 'TIMBERLAND'). If landarea='FOREST', COND_STATUS_CD = 1;
 #' if landarea='TIMBERLAND', SITECLCD in(1:6) & RESERVCD = 0.
@@ -276,19 +280,20 @@
 #' @export modGBtree
 modGBtree <- function(GBpopdat, 
                       estvar, 
-                      estvar.filter=NULL, 
-                      estseed="none", 
-                      landarea="FOREST", 
-                      pcfilter=NULL, 
-                      rowvar=NULL, 
-                      colvar=NULL, 
-                      sumunits=TRUE, 
-                      returntitle=FALSE, 
-                      savedata=FALSE, 
-                      table_opts=NULL, 
-                      title_opts=NULL, 
-                      savedata_opts=NULL, 
-                      gui=FALSE, 
+                      estvar.filter = NULL, 
+                      estseed = "none", 
+					  woodland = "Y",
+                      landarea = "FOREST", 
+                      pcfilter = NULL, 
+                      rowvar = NULL, 
+                      colvar = NULL, 
+                      sumunits = TRUE, 
+                      returntitle = FALSE, 
+                      savedata = FALSE, 
+                      table_opts = NULL, 
+                      title_opts = NULL, 
+                      savedata_opts = NULL, 
+                      gui = FALSE, 
                       ...){
 
   ##################################################################################
@@ -316,7 +321,7 @@ modGBtree <- function(GBpopdat,
   rawdata <- TRUE  
   
   ## Set global variables
-  ONEUNIT=n.total=n.strata=strwt=TOTAL=rowvar.filter=colvar.filter <- NULL
+  ONEUNIT=n.total=n.strata=strwt=TOTAL <- NULL
   
   
   ##################################################################
@@ -394,11 +399,9 @@ modGBtree <- function(GBpopdat,
     }
   }
 
-
   ##################################################################
   ## CHECK PARAMETER INPUTS
   ##################################################################
-  
   list.items <- c("condx", "pltcondx", "treex", "cuniqueid", "condid", 
 	                "tuniqueid", "ACI.filter", "unitarea", "unitvar", "stratalut",
                   "strvar", "plotsampcnt", "condsampcnt")
@@ -433,8 +436,10 @@ modGBtree <- function(GBpopdat,
   adj <- GBpopdat$adj
   strunitvars <- c(unitvar, strvar)
   strata <- GBpopdat$strata
+  pop_fmt <- GBpopdat$pop_fmt
+  pop_dsn <- GBpopdat$pop_dsn
+
 
- 
   ########################################
   ## Check area units
   ########################################
@@ -447,17 +452,17 @@ modGBtree <- function(GBpopdat,
   if (is.null(key(unitarea))) {
     setkeyv(unitarea, unitvar)
   }
-  
 
   ###################################################################################
   ## Check parameters and apply plot and condition filters
   ###################################################################################
-  estdat <- check.estdata(esttype=esttype, pltcondf=pltcondx, 
-                cuniqueid=cuniqueid, condid=condid, 
-                treex=treex, seedx=seedx, estseed=estseed, sumunits=sumunits, 
-                landarea=landarea, ACI.filter=ACI.filter, pcfilter=pcfilter, 
-                allin1=allin1, estround=estround, pseround=pseround, 
-                divideby=divideby, addtitle=addtitle, returntitle=returntitle, 
+  estdat <- check.estdata(esttype=esttype, pop_fmt=pop_fmt, pop_dsn=pop_dsn,
+                pltcondf=pltcondx, cuniqueid=cuniqueid, condid=condid, 
+                treex=treex, seedx=seedx, estseed=estseed, woodland=woodland,
+				sumunits=sumunits, landarea=landarea, ACI.filter=ACI.filter, 
+				pcfilter=pcfilter, allin1=allin1, 
+				estround=estround, pseround=pseround, divideby=divideby, 
+                addtitle=addtitle, returntitle=returntitle, 
                 rawdata=rawdata, rawonly=rawonly, savedata=savedata, 
                 outfolder=outfolder, overwrite_dsn=overwrite_dsn,
                 overwrite_layer=overwrite_layer, outfn.pre=outfn.pre, 
@@ -470,6 +475,7 @@ modGBtree <- function(GBpopdat,
   seedf <- estdat$seedf
   tuniqueid <- estdat$tuniqueid
   estseed <- estdat$estseed
+  woodland <- estdat$woodland
   sumunits <- estdat$sumunits
   landarea <- estdat$landarea
   allin1 <- estdat$allin1
@@ -487,6 +493,7 @@ modGBtree <- function(GBpopdat,
   raw_fmt <- estdat$raw_fmt
   raw_dsn <- estdat$raw_dsn
   rawfolder <- estdat$rawfolder
+  conn <- estdat$conn
 
   if ("STATECD" %in% names(pltcondf)) {
     states <- pcheck.states(sort(unique(pltcondf$STATECD)))
@@ -495,21 +502,21 @@ modGBtree <- function(GBpopdat,
     invyr <- sort(unique(pltcondf$INVYR))
   }
  
-  ###################################################################################
+  #############################################################################
   ### Check row and column data
-  ###################################################################################
-  rowcolinfo <- check.rowcol(gui=gui, esttype=esttype, treef=treef, seedf=seedf,
-	                condf=pltcondf, cuniqueid=cuniqueid, 
-	                tuniqueid=tuniqueid, estseed=estseed,
-	                rowvar=rowvar, rowvar.filter=rowvar.filter, 
-	                colvar=colvar, colvar.filter=colvar.filter, 
-	                row.FIAname=row.FIAname, col.FIAname=col.FIAname,
- 	                row.orderby=row.orderby, col.orderby=col.orderby, 
-	                row.add0=row.add0, col.add0=col.add0, 
-	                title.rowvar=title.rowvar, title.colvar=title.colvar, 
-	                rowlut=rowlut, collut=collut, rowgrp=rowgrp, 
-	                rowgrpnm=rowgrpnm, rowgrpord=rowgrpord, 
-	                landarea=landarea)
+  #############################################################################
+  rowcolinfo <- check.rowcol(gui=gui, esttype=esttype, conn=conn,
+                     treef=treef, seedf=seedf,
+                     condf=pltcondf, cuniqueid=cuniqueid,
+                     tuniqueid=tuniqueid, estseed=estseed,
+                     rowvar=rowvar, colvar=colvar,
+                     row.FIAname=row.FIAname, col.FIAname=col.FIAname,
+                     row.orderby=row.orderby, col.orderby=col.orderby,
+                     row.add0=row.add0, col.add0=col.add0,
+                     title.rowvar=title.rowvar, title.colvar=title.colvar,
+                     rowlut=rowlut, collut=collut, rowgrp=rowgrp,
+                     rowgrpnm=rowgrpnm, rowgrpord=rowgrpord,
+                     landarea=landarea, states=states)
   treef <- rowcolinfo$treef
   seedf <- rowcolinfo$seedf
   condf <- rowcolinfo$condf
@@ -539,34 +546,47 @@ modGBtree <- function(GBpopdat,
     uniquecol[[unitvar]] <- factor(uniquecol[[unitvar]])
   }
 
-  #####################################################################################
+  ###############################################################################
   ### Get estimation data from tree table
-  #####################################################################################
+  ###############################################################################
   adjtree <- ifelse(adj %in% c("samp", "plot"), TRUE, FALSE)
   treedat <- check.tree(gui=gui, treef=treef, seedf=seedf, estseed=estseed,
                   bycond=TRUE, condf=condf, bytdom=bytdom, 
                   tuniqueid=tuniqueid, cuniqueid=cuniqueid, 
                   esttype=esttype, estvarn=estvar, estvarn.filter=estvar.filter, 
                   esttotn=TRUE, tdomvar=tdomvar, tdomvar2=tdomvar2, 
-                  adjtree=adjtree, metric=metric)
+                  adjtree=adjtree, metric=metric, woodland=woodland)
   if (is.null(treedat)) return(NULL) 
   tdomdat <- treedat$tdomdat
 
   if (rowvar != "TOTAL") {
-    if (!row.add0) {
+    #if (!row.add0) {
       if (any(is.na(tdomdat[[rowvar]]))) {
-        tdomdat <- tdomdat[!is.na(tdomdat[[rowvar]]), ]
-      }
-    }
-    if (colvar != "NONE") {
-      if (!col.add0) {
-        if (any(is.na(tdomdat[[colvar]]))) {
-          tdomdat <- tdomdat[!is.na(tdomdat[[colvar]]), ]
+	    if (!row.FIAname) {
+		  rval <- ifelse (any(!is.na(tdomdat[[rowvar]]) & tdomdat[[rowvar]] == 0), max(tdomdat[[rowvar]], na.rm=TRUE), 0)
+		  tdomdat[is.na(tdomdat[[rowvar]]), rowvar] <- rval
+		  levels(uniquerow[[rowvar]]) <- c(levels(uniquerow[[rowvar]]), as.character(rval))
+		  uniquerow[is.na(uniquerow[[rowvar]]), rowvar] <- as.character(rval)
+        } else {
+          tdomdat <- tdomdat[!is.na(tdomdat[[rowvar]]), ]
         }
-      }
+	   }
+    #}
+    if (colvar != "NONE") {
+      #if (!col.add0) {
+        if (any(is.na(tdomdat[[colvar]]))) {
+	      if (!col.FIAname) {
+		    cval <- ifelse (any(!is.na(tdomdat[[colvar]]) & tdomdat[[colvar]] == 0), max(tdomdat[[colvar]], na.rm=TRUE), 0)
+		    tdomdat[is.na(tdomdat[[colvar]]), colvar] <- cval
+			levels(uniquecol[[colvar]]) <- c(levels(uniquecol[[colvar]]), as.character(cval))
+			uniquecol[is.na(uniquecol[[colvar]]), colvar] <- as.character(cval)
+		  } else {
+            tdomdat <- tdomdat[!is.na(tdomdat[[colvar]]), ]
+          }
+		}
+      #}
     }
-  }
-  
+  } 
   ## Merge tdomdat with condx
   xchk <- check.matchclass(condx, tdomdat, c(cuniqueid, condid))
   condx <- xchk$tab1
@@ -579,14 +599,16 @@ modGBtree <- function(GBpopdat,
   tdomvarlst <- treedat$tdomvarlst
   estunits <- treedat$estunits
  
-  #####################################################################################
+  ###############################################################################
   ### Get titles for output tables
-  #####################################################################################
-  alltitlelst <- check.titles(dat=tdomdat, esttype=esttype, estseed=estseed, 
+  ###############################################################################
+  alltitlelst <- check.titles(dat=tdomdat, esttype=esttype, 
+                    estseed=estseed, woodland=woodland, 
 	                sumunits=sumunits, title.main=title.main, title.ref=title.ref, 
 	                title.rowvar=title.rowvar, title.rowgrp=title.rowgrp, 
 	                title.colvar=title.colvar, title.unitvar=title.unitvar, 
-	                title.filter=title.filter, title.unitsn=estunits, title.estvarn=title.estvar, 
+	                title.filter=title.filter, title.unitsn=estunits, 
+					title.estvarn=title.estvar, 
 	                unitvar=unitvar, rowvar=rowvar, colvar=colvar, 
  	                estvarn=estvar, estvarn.filter=estvar.filter, 
 	                addtitle=addtitle, returntitle=returntitle, 
@@ -603,7 +625,7 @@ modGBtree <- function(GBpopdat,
   if (rawdata) {
     outfn.rawdat <- alltitlelst$outfn.rawdat
   }
- 
+
   ############################################################################
   ## GENERATE ESTIMATES
   ############################################################################
@@ -643,7 +665,6 @@ modGBtree <- function(GBpopdat,
     tdomdatsum <- tdomdat[, lapply(.SD, sum, na.rm=TRUE), 
 		    by=c(strunitvars, cuniqueid, rowvar), .SDcols=estvar.name]
     tdomdatsum <- tdomdatsum[!is.na(tdomdatsum[[rowvar]]),]
-
     unit_rowest <- GBest.pbar(sumyn = estvar.name, 
                               ysum = tdomdatsum,
                               uniqueid = cuniqueid, 
@@ -651,7 +672,7 @@ modGBtree <- function(GBpopdat,
                               unitvar = unitvar, 
                               strvar = strvar, 
                               domain = rowvar)
-
+							  
     if (colvar != "NONE") {
       tdomdatsum <- tdomdat[, lapply(.SD, sum, na.rm=TRUE), 
 		      by=c(strunitvars, cuniqueid, colvar), .SDcols=estvar.name]
