@@ -14,7 +14,7 @@
 #' TPA_UNADJ=6.018046 for trees on subplot; 74.965282 for trees on
 #' microplot).\cr \tab cond \tab cuniqueid \tab Unique identifier for each
 #' plot, to link to pltassgn (ex. PLT_CN).\cr \tab \tab CONDID \tab Unique
-#' identfier of each condition on plot.  Set CONDID=1, if only 1 condition per
+#' identifier of each condition on plot.  Set CONDID=1, if only 1 condition per
 #' plot.\cr \tab \tab CONDPROP_UNADJ \tab Unadjusted proportion of condition on
 #' each plot.  Set CONDPROP_UNADJ=1, if only 1 condition per plot.\cr \tab \tab
 #' COND_STATUS_CD \tab Status of each forested condition on plot (i.e.
@@ -51,6 +51,10 @@
 #' syntax (e.g., 'STATUSCD == 1').
 #' @param estseed String. Use seedling data only or add to tree data. Seedling
 #' estimates are only for counts (estvar='TPA_UNADJ')-('none', 'only', 'add').
+#' @param woodland String. If woodland = 'Y', include woodland tree species  
+#' where measured. If woodland = 'N', only include timber species. See 
+#' FIESTA::ref_species$WOODLAND ='Y/N'. If woodland = 'only', only include
+#' woodland species.
 #' @param landarea String. The condition-level filter for defining land area
 #' ('ALL', 'FOREST', 'TIMBERLAND'). If landarea='FOREST', COND_STATUS_CD = 1;
 #' if landarea='TIMBERLAND', SITECLCD in(1:6) & RESERVCD = 0.
@@ -65,7 +69,9 @@
 #' an input data frame (i.e., plt, cond, tree).
 #' @param prednames String vector. Name(s) of predictor variables to include in
 #' model.
-#' @param modelselect Logical. If TRUE, variable selection occurs. 
+#' @param modelselect Logical. If TRUE, an elastic net regression model is fit 
+#' to the entire plot level data, and the variables selected in that model are 
+#' used for the proceeding estimation.
 #' @param FIA Logical. If TRUE, the finite population term is removed from
 #' estimator to match FIA estimates.
 #' @param bootstrap Logical. If TRUE, returns bootstrap variance estimates,
@@ -80,6 +86,9 @@
 #' @param savedata_opts List. See help(savedata_options()) for a list
 #' of options. Only used when savedata = TRUE.  
 #' @param gui Logical. If gui, user is prompted for parameters.
+#' @param modelselect_bydomain Logical. If TRUE, modelselection will occur at 
+#' the domain level as specified by rowvar and/or colvar and not at the level of
+#' the entire sample.
 #' @param ...  Parameters for modMApop() if MApopdat is NULL.
 #' @return If FIA=TRUE or unitvar=NULL and colvar=NULL, one data frame is
 #' returned with tree estimates and percent sample errors. Otherwise, a list is
@@ -248,17 +257,21 @@
 #'                      
 #' # Use GREG Estimator to Estimate cubic foot volume of live trees in our
 #' # population
-#' modMAtree(MApopdat = MApopdat,
+#' mod1 <- modMAtree(MApopdat = MApopdat,
 #'           MAmethod = "greg",
 #'           estvar = "VOLCFNET",
 #'           estvar.filter = "STATUSCD == 1")
 #'           
+#' str(mod1)
+#'           
 #' # Use GREG Elastic Net Estimator to Estimate basal area of live trees in our
 #' # population
-#' modMAtree(MApopdat = MApopdat,
+#' mod2 <- modMAtree(MApopdat = MApopdat,
 #'           MAmethod = "gregEN",
 #'           estvar = "BA",
 #'           estvar.filter = "STATUSCD == 1")
+#'           
+#' str(mod2)
 #' }
 #' @export modMAtree
 modMAtree <- function(MApopdat, 
@@ -266,6 +279,7 @@ modMAtree <- function(MApopdat,
                       estvar, 
                       estvar.filter = NULL, 
                       estseed = "none", 
+					            woodland = "Y",
                       landarea = "FOREST", 
                       pcfilter = NULL, 
                       rowvar = NULL, 
@@ -280,12 +294,13 @@ modMAtree <- function(MApopdat,
                       title_opts = NULL, 
                       savedata_opts = NULL, 
                       gui = FALSE, 
+                      modelselect_bydomain = FALSE,
                       ...){
 
-  ########################################################################################
+  ##################################################################################
   ## DESCRIPTION: 
   ## Generates model-assisted estimates by domain (and estimation unit)
-  ######################################################################################
+  ##################################################################################
 
   ## CHECK GUI - IF NO ARGUMENTS SPECIFIED, ASSUME GUI=TRUE
   if (nargs() == 0 && is.null(MApopdat)) {
@@ -307,7 +322,7 @@ modMAtree <- function(MApopdat,
   sumunits <- FALSE
   
   ## Set global variables
-  ONEUNIT=n.total=n.strata=strwt=TOTAL=rowvar.filter=colvar.filter <- NULL
+  ONEUNIT=n.total=n.strata=strwt=TOTAL <- NULL
   rawdata <- TRUE 
   
   
@@ -470,15 +485,15 @@ modMAtree <- function(MApopdat,
   if (is.null(key(unitarea))) {
     setkeyv(unitarea, unitvar)
   }
-  
-  
+     
   ###################################################################################
   ## Check parameters and apply plot and condition filters
   ###################################################################################
   estdat <- check.estdata(esttype=esttype, pltcondf=pltcondx, 
                 cuniqueid=cuniqueid, condid=condid, treex=treex, seedx=seedx, 
-                estseed=estseed, sumunits=sumunits, landarea=landarea, 
-                ACI.filter=ACI.filter, pcfilter=pcfilter, allin1=allin1, 
+                estseed=estseed, woodland=woodland, 
+				sumunits=sumunits, landarea=landarea, 
+				ACI.filter=ACI.filter, pcfilter=pcfilter, allin1=allin1, 
                 estround=estround, pseround=pseround, divideby=divideby, 
                 addtitle=addtitle, returntitle=returntitle, 
                 rawdata=rawdata, rawonly=rawonly, savedata=savedata, 
@@ -493,6 +508,7 @@ modMAtree <- function(MApopdat,
   seedf <- estdat$seedf
   tuniqueid <- estdat$tuniqueid
   estseed <- estdat$estseed
+  woodland <- estdat$woodland
   sumunits <- estdat$sumunits
   landarea <- estdat$landarea
   allin1 <- estdat$allin1
@@ -523,8 +539,7 @@ modMAtree <- function(MApopdat,
   rowcolinfo <- check.rowcol(gui=gui, esttype=esttype, treef=treef, seedf=seedf, 
                     condf=pltcondf, cuniqueid=cuniqueid, 
                     tuniqueid=tuniqueid, estseed=estseed,
-                    rowvar=rowvar, rowvar.filter=rowvar.filter, 
-                    colvar=colvar, colvar.filter=colvar.filter, 
+                    rowvar=rowvar, colvar=colvar, 
                     row.FIAname=row.FIAname, col.FIAname=col.FIAname, 
                     row.orderby=row.orderby, col.orderby=col.orderby, 
                     row.add0=row.add0, col.add0=col.add0, 
@@ -560,34 +575,48 @@ modMAtree <- function(MApopdat,
     uniquecol[[unitvar]] <- factor(uniquecol[[unitvar]])
   }
 
-  #####################################################################################
+  #################################################################################
   ### GET ESTIMATION DATA FROM TREE TABLE
-  #####################################################################################
+  #################################################################################
   adjtree <- ifelse(adj %in% c("samp", "plot"), TRUE, FALSE)
   treedat <- check.tree(gui=gui, treef=treef, seedf=seedf, estseed=estseed, 
                   bycond=TRUE, condf=condf, bytdom=bytdom, 
                   tuniqueid=tuniqueid, cuniqueid=cuniqueid, 
                   esttype=esttype, estvarn=estvar, estvarn.filter=estvar.filter, 
                   esttotn=TRUE, tdomvar=tdomvar, tdomvar2=tdomvar2, 
-                  adjtree=adjtree, metric=metric)
+                  adjtree=adjtree, metric=metric, woodland=woodland)
   if (is.null(treedat)) return(NULL)
   tdomdat <- treedat$tdomdat
 
   if (rowvar != "TOTAL") {
-    if (!row.add0) {
+    #if (!row.add0) {
       if (any(is.na(tdomdat[[rowvar]]))) {
-        tdomdat <- tdomdat[!is.na(tdomdat[[rowvar]]), ]
-      }
-    }
-    if (colvar != "NONE") {
-      if (!col.add0) {
-        if (any(is.na(tdomdat[[colvar]]))) {
-          tdomdat <- tdomdat[!is.na(tdomdat[[colvar]]), ]
+	    if (!row.FIAname) {
+		  rval <- ifelse (any(!is.na(tdomdat[[rowvar]]) & tdomdat[[rowvar]] == 0), max(tdomdat[[rowvar]], na.rm=TRUE), 0)
+		  tdomdat[is.na(tdomdat[[rowvar]]), rowvar] <- rval
+		  levels(uniquerow[[rowvar]]) <- c(levels(uniquerow[[rowvar]]), as.character(rval))
+		  uniquerow[is.na(uniquerow[[rowvar]]), rowvar] <- as.character(rval)
+        } else {
+          tdomdat <- tdomdat[!is.na(tdomdat[[rowvar]]), ]
         }
-      }
+	   }
+    #}
+    if (colvar != "NONE") {
+      #if (!col.add0) {
+        if (any(is.na(tdomdat[[colvar]]))) {
+	      if (!col.FIAname) {
+		    cval <- ifelse (any(!is.na(tdomdat[[colvar]]) & tdomdat[[colvar]] == 0), max(tdomdat[[colvar]], na.rm=TRUE), 0)
+		    tdomdat[is.na(tdomdat[[colvar]]), colvar] <- cval
+			levels(uniquecol[[colvar]]) <- c(levels(uniquecol[[colvar]]), as.character(cval))
+			uniquecol[is.na(uniquecol[[colvar]]), colvar] <- as.character(cval)
+		  } else {
+            tdomdat <- tdomdat[!is.na(tdomdat[[colvar]]), ]
+          }
+		}
+      #}
     }
   }
-
+  
   ## Merge tdomdat with condx
   xchk <- check.matchclass(condx, tdomdat, c(cuniqueid, condid))
   condx <- xchk$tab1
@@ -600,9 +629,10 @@ modMAtree <- function(MApopdat,
   tdomvarlst <- treedat$tdomvarlst
   estunits <- treedat$estunits
 
-  #####################################################################################
+
+  #################################################################################
   ### GET TITLES FOR OUTPUT TABLES
-  #####################################################################################
+  #################################################################################
   alltitlelst <- check.titles(dat=tdomdat, esttype=esttype, estseed=estseed, 
                       sumunits=sumunits, title.main=title.main, title.ref=title.ref, 
                       title.rowvar=title.rowvar, title.rowgrp=title.rowgrp, 
@@ -628,9 +658,9 @@ modMAtree <- function(MApopdat,
   ## Append name of package and method to outfile name
   outfn.estpse <- paste0(outfn.estpse, "_modMA_mase", "_", MAmethod) 
 
-  #####################################################################################
+  #################################################################################
   ## GENERATE ESTIMATES
-  #####################################################################################
+  #################################################################################
   unit_totest=unit_rowest=unit_colest=unit_grpest=rowunit=totunit <- NULL
   addtotal <- ifelse(((rowvar == "TOTAL" || length(unique(tdomdat[[rowvar]])) > 1) ||
 		(!is.null(tdomvarlst) && length(tdomvarlst) > 1)), TRUE, FALSE)
@@ -642,6 +672,44 @@ modMAtree <- function(MApopdat,
 	ifelse(MAmethod == "gregEN", "gregElasticNet", 
 	ifelse(MAmethod == "ratio", "ratioEstimator", "horvitzThompson"))))
   message("generating estimates using mase::", masemethod, " function...\n")
+  
+  predselect.overall <- NULL
+  if (MAmethod == "greg" && modelselect == T) {
+    
+    # want to do variable selection on plot level data...
+    pltlvl <- tdomdat[ , lapply(.SD, sum, na.rm = TRUE), 
+                       by=c(unitvar, cuniqueid, "TOTAL", strvar, prednames),
+                       .SDcols=response]
+    
+    y <- pltlvl[[response]]
+    xsample <- pltlvl[ , prednames, with = F, drop = F]
+    
+    # need to go means -> totals -> summed totals
+    xpop <- unitlut[ , c(unitvar, prednames), with = F, drop = F]
+    xpop_npix <- merge(xpop, npixels, by = unitvar, all.x = TRUE)
+    # multiply unitvar level population means by corresponding npixel values to get population level totals
+    xpop_npix[ ,2:ncol(xpop)] <- lapply(xpop_npix[ ,2:ncol(xpop)], function(x) xpop_npix[["npixels"]] * x)
+    # sum those values
+    xpop_totals <- colSums(xpop_npix[ ,2:ncol(xpop)])
+    # format xpop for mase input
+    xpop_totals <- data.frame(as.list(xpop_totals))
+    
+    N <- sum(npixels[["npixels"]])
+    
+    # since we want to do modelselection + get the coefficients, just use MAest.greg
+    coefs_select <- MAest.greg(y = y,
+                               N = N,
+                               x_sample = setDF(xsample),
+                               x_pop = xpop_totals,
+                               modelselect = TRUE)
+    
+    predselect.overall <- coefs_select$predselect
+    prednames <- names(predselect.overall[ ,(!is.na(predselect.overall))[1,], with = F])
+    message(paste0("Predictors ", "[", paste0(prednames, collapse = ", "), "]", " were chosen in model selection.\n"))
+  
+      
+  }
+  
   if (!MAmethod %in% c("HT", "PS")) {
     message("using the following predictors...", toString(prednames))
   }
@@ -667,7 +735,7 @@ modMAtree <- function(MApopdat,
                         unitlut=unitlut, unitvar=unitvar, esttype=esttype, 
                         MAmethod=MAmethod, strvar=strvar, prednames=prednames, 
                         domain="TOTAL", response=response, npixels=npixels, 
-                        FIA=FIA, modelselect=modelselect, getweights=getweights,
+                        FIA=FIA, modelselect=modelselect_bydomain, getweights=getweights,
                         var_method=var_method)
     unit_totest <- do.call(rbind, sapply(unit_totestlst, '[', "unitest"))
     unit_weights <- do.call(rbind, sapply(unit_totestlst, '[', "weights")) 
@@ -696,7 +764,7 @@ modMAtree <- function(MApopdat,
                         unitlut=unitlut, unitvar=unitvar, esttype=esttype, 
                         MAmethod=MAmethod, strvar=strvar, prednames=prednames, 
                         domain=rowvar, response=response, npixels=npixels, 
-                        FIA=FIA, modelselect=modelselect, getweights=getweights,
+                        FIA=FIA, modelselect=modelselect_bydomain, getweights=getweights,
                         var_method=var_method)
     unit_rowest <- do.call(rbind, sapply(unit_rowestlst, '[', "unitest"))
     if (MAmethod %in% c("greg", "gregEN")) {
@@ -711,7 +779,7 @@ modMAtree <- function(MApopdat,
                             unitlut=unitlut, unitvar=unitvar, esttype=esttype, 
                             MAmethod=MAmethod, strvar=strvar, prednames=prednames, 
                             domain=colvar, response=response, npixels=npixels, 
-                            FIA=FIA, modelselect=modelselect, var_method=var_method)
+                            FIA=FIA, modelselect=modelselect_bydomain, var_method=var_method)
       unit_colest <- do.call(rbind, sapply(unit_colestlst, '[', "unitest"))
       if (MAmethod %in% c("greg", "gregEN")) {
         predselectlst$colest <- do.call(rbind, sapply(unit_colestlst, '[', "predselect"))
@@ -726,7 +794,7 @@ modMAtree <- function(MApopdat,
                                unitlut=unitlut, unitvar=unitvar, esttype=esttype, 
                                MAmethod=MAmethod, strvar=strvar, prednames=prednames, 
                                domain="grpvar", response=response, npixels=npixels, 
-                               FIA=FIA, modelselect=modelselect, var_method=var_method)
+                               FIA=FIA, modelselect=modelselect_bydomain, var_method=var_method)
       unit_grpest <- do.call(rbind, sapply(unit_grpestlst, '[', "unitest"))
       if (MAmethod %in% c("greg", "gregEN")) {
         predselectlst$grpest <- do.call(rbind, sapply(unit_grpestlst, '[', "predselect"))
@@ -738,9 +806,9 @@ modMAtree <- function(MApopdat,
     }
   }
 
-  ###################################################################################
+  ###############################################################################
   ## Check add0 and Add area
-  ###################################################################################
+  ###############################################################################
   if (!sumunits && nrow(unitarea) > 1) col.add0 <- TRUE
   if (!is.null(unit_rowest)) {
     unit_rowest <- add0unit(x=unit_rowest, xvar=rowvar, uniquex=uniquerow, 
@@ -809,9 +877,9 @@ modMAtree <- function(MApopdat,
     setkeyv(unit_grpest, c(unitvar, rowvar, colvar))
   }
  
-  ###################################################################################
+  ###############################################################################
   ## GENERATE OUTPUT TABLES
-  ###################################################################################
+  ###############################################################################
   message("getting output...")
   estnm <- "est"
   tabs <- est.outtabs(esttype=esttype, sumunits=sumunits, areavar=areavar, 
@@ -886,6 +954,7 @@ modMAtree <- function(MApopdat,
     rawdat$module <- "MA"
     rawdat$esttype <- "TREE"
     rawdat$MAmethod <- MAmethod
+    rawdat$predselect.overall <- predselect.overall
     rawdat$predselectlst <- predselectlst
     rawdat$estvar <- estvar
     rawdat$estvar.filter <- estvar.filter
